@@ -23,6 +23,7 @@ import logging
 import errno
 import six
 
+from vdsm.network import dns
 from vdsm.network.ip.address import ipv6_supported
 from vdsm.network.ip import dhclient
 from vdsm.network.ipwrapper import getLinks
@@ -33,9 +34,7 @@ from vdsm.network.netconfpersistence import RunningConfig
 from .addresses import getIpAddrs, getIpInfo, is_ipv6_local_auto
 from . import bonding
 from . import bridges
-from .dns import get_host_nameservers
 from . import nics
-from . import vlans
 from .routes import get_routes, get_gateway, is_default_route
 from .qos import report_network_qos
 
@@ -66,7 +65,7 @@ def _get(vdsmnets=None):
     networking_report = {'networks': nets_info}
     networking_report.update(devices_info)
 
-    networking_report['nameservers'] = get_host_nameservers()
+    networking_report['nameservers'] = dns.get_host_nameservers()
     networking_report['supportsIPv6'] = ipv6_supported()
 
     return networking_report
@@ -109,7 +108,8 @@ def _devices_report(ipaddrs, routes):
             devinfo.update(bonding.get_bond_agg_info(dev.name))
             devinfo.update(LEGACY_SWITCH)
         elif dev.isVLAN():
-            devinfo = devs_report['vlans'][dev.name] = vlans.info(dev)
+            devinfo = devs_report['vlans'][dev.name] = {'iface': dev.device,
+                                                        'vlanid': dev.vlanid}
         else:
             continue
         devinfo.update(_devinfo(dev, routes, ipaddrs))
