@@ -41,9 +41,9 @@ import zipfile
 
 import libvirt
 
-from vdsm import libvirtconnection
 from vdsm.common import cmdutils
 from vdsm.common import concurrent
+from vdsm.common import libvirtconnection
 from vdsm.common import password
 from vdsm.common import response
 from vdsm.common import zombiereaper
@@ -285,7 +285,7 @@ def abort_job(job_id):
 
 def get_jobs_status():
     ret = {}
-    with _lock:
+    with _lock:  # pylint: disable=not-context-manager
         items = tuple(_jobs.items())
     for job_id, job in items:
         ret[job_id] = {
@@ -297,21 +297,21 @@ def get_jobs_status():
 
 
 def _add_job(job_id, job):
-    with _lock:
+    with _lock:  # pylint: disable=not-context-manager
         if job_id in _jobs:
             raise JobExistsError("Job %r exists" % job_id)
         _jobs[job_id] = job
 
 
 def _get_job(job_id):
-    with _lock:
+    with _lock:  # pylint: disable=not-context-manager
         if job_id not in _jobs:
             raise NoSuchJob("No such job %r" % job_id)
         return _jobs[job_id]
 
 
 def _remove_job(job_id):
-    with _lock:
+    with _lock:  # pylint: disable=not-context-manager
         if job_id not in _jobs:
             raise NoSuchJob("No such job %r" % job_id)
         del _jobs[job_id]
@@ -791,25 +791,20 @@ class PipelineProc(object):
 
         If timeout is provided, it is set as the upper limit for the wait
         period.
-        Note that the timeout granularity is 1 sec, therefore, the actual
-        applied timeout may drift by 1 sec.
         """
         if timeout is not None:
             deadline = monotonic_time() + timeout
-            # NOTE: we do not want to use Popen's auto-killing timeout
-            if self.returncode is not None:
-                return True
-            while monotonic_time() < deadline:
-                time.sleep(1)
-                if self.returncode is not None:
-                    return True
 
+            for p in self._procs:
+                try:
+                    p.wait(deadline - monotonic_time())
+                except subprocess.TimeoutExpired:
+                    return False
         else:
             for p in self._procs:
                 p.wait()
-            return True
 
-        return False
+        return True
 
 
 class ImportVm(object):
@@ -1364,7 +1359,8 @@ def _read_ovf_from_tar_ova(ova_path):
     with tarfile.open(ova_path) as tar:
         for member in tar:
             if member.name.endswith('.ovf'):
-                with closing(tar.extractfile(member)) as ovf:
+                ovf = tar.extractfile(member)
+                with closing(ovf):
                     return ovf.read()
         raise ClientError('OVA does not contains file with .ovf suffix')
 
