@@ -206,6 +206,10 @@ def send_metrics(vms_stats):
                 data[prefix + '.balloon.cur'] = \
                     stat['balloonInfo']['balloon_cur']
 
+            if 'memoryStats' in stat:
+                for k, v in six.iteritems(stat['memoryStats']):
+                    data[prefix + '.mem.' + k] = v
+
             if 'disks' in stat:
                 for disk in stat['disks']:
                     diskprefix = prefix + '.disk.' + disk
@@ -319,7 +323,7 @@ def networks(vm, stats, first_sample, last_sample, interval):
     last_indexes = _find_bulk_stats_reverse_map(last_sample, 'net')
 
     for nic in vm.getNicDevices():
-        if nic.name.startswith('hostdev'):
+        if nic.is_hostdevice:
             continue
 
         # may happen if nic is a new hot-plugged one
