@@ -827,6 +827,16 @@ _STORAGE_TEST_DATA = [
             <boot order="1"/>
             <driver name="qemu" io="native" type="qcow2"
               error_policy="stop" cache="none"/>
+            <alias name="ua-58ca6050-0134-00d6-0053-000000000388"/>
+        </disk>''',
+     {}],
+    # cache attribute taken from XML for non-transient disks
+    [u'''<disk device="disk" snapshot="no" type="file">
+            <source file="/path/to/volume"/>
+            <target bus="sata" dev="sda"/>
+            <serial>54-a672-23e5b495a9ea</serial>
+            <driver cache="writethrough" error_policy="enospace"
+                    io="threads" name="qemu" type="raw"/>
         </disk>''',
      {}],
 ]
